--- old/usr/src/man/man3c/wcsrtombs.3c	Sun Jun 29 11:52:28 2014
+++ new/usr/src/man/man3c/wcsrtombs.3c	Sun Jun 29 11:52:28 2014
@@ -7,7 +7,7 @@
 .\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
 .\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
 .\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH WCSRTOMBS 3C "Nov 1, 2003"
+.TH WCSRTOMBS 3C "Jun 25, 2014"
 .SH NAME
 wcsrtombs, wcsrtombs_l \- convert a wide-character string to a character string
 (restartable)
@@ -19,14 +19,17 @@
 \fBsize_t\fR \fBwcsrtombs\fR(\fBchar *restrict\fR \fIdst\fR,
      \fBconst wchar_t **restrict\fR \fIsrc\fR, \fBsize_t\fR \fIlen\fR,
      \fBmbstate_t *restrict\fR \fIps\fR);
+.fi
+.LP
+.nf
+#include <wchar.h>
+#include <xlocale.h>
 
 \fBsize_t\fR \fBwcsrtombs_l\fR(\fBchar *restrict\fR \fIdst\fR,
      \fBconst wchar_t **restrict\fR \fIsrc\fR, \fBsize_t\fR \fIlen\fR,
      \fBmbstate_t *restrict\fR \fIps\fR, \fBlocale_t\fR \fIloc\fR);
 .fi
-
 .SH DESCRIPTION
-.sp
 .LP
 The \fBwcsrtombs()\fR function converts a sequence of wide-characters from the
 array indirectly pointed to by \fIsrc\fR into a sequence of corresponding
@@ -49,10 +52,8 @@
 stored in the array pointed to by \fIdst\fR (and \fIdst\fR is not a null
 pointer).
 .RE
-.sp
 .LP
 Each conversion takes place as if by a call to the \fBwcrtomb()\fR function.
-.sp
 .LP
 If \fIdst\fR is not a null pointer, the pointer object pointed to by \fIsrc\fR
 is assigned either a null pointer (if conversion stopped due to reaching a
@@ -60,36 +61,31 @@
 wide-character converted (if any). If conversion stopped due to reaching a
 terminating null wide-character, the resulting state described is the initial
 conversion state.
-.sp
 .LP
 If \fIps\fR is a null pointer, the \fBwcsrtombs()\fR function uses its own
 internal \fBmbstate_t\fR object, which is initialized at program startup to the
 initial conversion state.  Otherwise, the  \fBmbstate_t\fR object pointed to by
 \fIps\fR is used to completely describe the current conversion state of the
-associated character sequence. Solaris will behave as if no function defined in
-the Solaris Reference Manual calls \fBwcsrtombs()\fR.
-.sp
+associated character sequence. The system will behave as if no function defined
+in the Reference Manual calls any of these functions.
 .LP
-The behavior of this function is affected by the \fBLC_CTYPE\fR category of the
-current locale.  See \fBenviron\fR(5).
-.sp
+The behavior of \fBwcsrtombs()\fR is affected by the \fBLC_CTYPE\fR category of
+the current locale.  See \fBenviron\fR(5).
 .LP
 The function \fBwcsrtombs_l()\fR behaves identically to \fBwcsrtombs\fR, except
-instead of operating in the current environemtn, it operates in the environment
+instead of operating in the current locale, it operates in the locale
 specified by \fIloc\fR.
 .SH RETURN VALUES
-.sp
 .LP
 If conversion stops because a code is reached that does not correspond to a
-valid character, an encoding error occurs.  In this case, the \fBwcsrtombs()\fR
-function stores the value of the macro \fBEILSEQ\fR in \fBerrno\fR and returns
-\fB(size_t)\(mi1\fR; the conversion state is undefined.  Otherwise, it returns
+valid character, an encoding error occurs.  In this case, these
+functions store the value of the macro \fBEILSEQ\fR in \fBerrno\fR and return
+\fB(size_t)\(mi1\fR; the conversion state is undefined.  Otherwise, they return
 the number of bytes in the resulting character sequence, not including the
 terminating null (if any).
 .SH ERRORS
-.sp
 .LP
-The \fBwcsrtombs()\fR function may fail if:
+The \fBwcsrtombs()\fR and \fBwcsrtombs_l()\fR functions may fail if:
 .sp
 .ne 2
 .na
@@ -108,23 +104,9 @@
 .RS 10n
 A wide-character code does not correspond to a valid character.
 .RE
-
-.SH USAGE
-.sp
-.LP
-If \fIps\fR is not a null pointer, \fBwcsrtombs()\fR uses the \fBmbstate_t\fR
-object pointed to by \fIps\fR and the function can be used safely in
-multithreaded applications, as long as \fBsetlocale\fR(3C) is not being called
-to change the locale. If \fIps\fR is a null pointer, \fBwcsrtombs()\fR uses its
-internal \fBmbstate_t\fR object and the function is Unsafe in multithreaded
-applications.
 .SH ATTRIBUTES
-.sp
 .LP
 See \fBattributes\fR(5) for descriptions of the following attributes:
-.sp
-
-.sp
 .TS
 box;
 c | c
@@ -131,13 +113,19 @@
 l | l .
 ATTRIBUTE TYPE	ATTRIBUTE VALUE
 _
-Interface Stability	Standard
+Interface Stability	See below.
 _
-MT-Level	See NOTES below
+MT-Level	See below.
 .TE
 
+.LP
+The \fBwcsrtombs()\fR function is Standard.  The \fBwcsrtombs_l()\fR
+function is Uncommitted.
+.LP
+If \fIps\fR is a null pointer, these functions should be considered Unsafe
+for use in multithreaded applications.  Otherwise, they are MT-Safe.
 .SH SEE ALSO
-.sp
 .LP
-\fBmbsinit\fR(3C), \fBsetlocale\fR(3C), \fBwcrtomb\fR(3C), \fBattributes\fR(5),
+\fBmbsinit\fR(3C), \fBnewlocale\fR(3C), \fBsetlocale\fR(3C), \fBuselocale\fR(3C),
+\fBwcrtomb\fR(3C), \fBattributes\fR(5),
 \fBenviron\fR(5), \fBstandards\fR(5)
